@@ -23,14 +23,6 @@
 
 G_BEGIN_DECLS
 
-typedef enum
-{
-  EPHY_PREFS_UI_TABS_BAR_POSITION_TOP,
-  EPHY_PREFS_UI_TABS_BAR_POSITION_BOTTOM,
-  EPHY_PREFS_UI_TABS_BAR_POSITION_LEFT,
-  EPHY_PREFS_UI_TABS_BAR_POSITION_RIGHT
-} EphyPrefsUITabsBarPosition;
-
 typedef enum
 {
   EPHY_PREFS_READER_FONT_STYLE_SANS,
@@ -57,13 +49,6 @@ typedef enum
   EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY_NEVER
 } EphyPrefsUITabsBarVisibilityPolicy;
 
-typedef enum
-{
-  EPHY_PREFS_WEB_COOKIES_POLICY_ALWAYS,
-  EPHY_PREFS_WEB_COOKIES_POLICY_NO_THIRD_PARTY,
-  EPHY_PREFS_WEB_COOKIES_POLICY_NEVER
-} EphyPrefsWebCookiesPolicy;
-
 typedef enum
 {
   EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ON_DEMAND,
@@ -73,7 +58,6 @@ typedef enum
 
 #define EPHY_PREFS_UI_SCHEMA                     "org.gnome.Epiphany.ui"
 #define EPHY_PREFS_UI_EXPAND_TABS_BAR            "expand-tabs-bar"
-#define EPHY_PREFS_UI_TABS_BAR_POSITION          "tabs-bar-position"
 #define EPHY_PREFS_UI_TABS_BAR_VISIBILITY_POLICY "tabs-bar-visibility-policy"
 #define EPHY_PREFS_UI_KEEP_WINDOW_OPEN           "keep-window-open"
 
@@ -107,15 +91,14 @@ static const char * const ephy_prefs_state_schema[] = {
 #define EPHY_PREFS_WEB_ENABLE_USER_JS               "enable-user-js"
 #define EPHY_PREFS_WEB_ENABLE_POPUPS                "enable-popups"
 #define EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING        "enable-spell-checking"
-#define EPHY_PREFS_WEB_ENABLE_SMOOTH_SCROLLING      "enable-smooth-scrolling"
 #define EPHY_PREFS_WEB_USER_AGENT                   "user-agent"
-#define EPHY_PREFS_WEB_COOKIES_POLICY               "cookies-policy"
 #define EPHY_PREFS_WEB_DEFAULT_ENCODING             "default-encoding"
 #define EPHY_PREFS_WEB_ENABLE_ADBLOCK               "enable-adblock"
 #define EPHY_PREFS_WEB_REMEMBER_PASSWORDS           "remember-passwords"
 #define EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS  "enable-site-specific-quirks"
 #define EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING         "enable-safe-browsing"
-#define EPHY_PREFS_WEB_GSB_API_KEY                  "gsb-api-key"
+#define EPHY_PREFS_WEB_ENABLE_ITP                   "enable-itp"
+#define EPHY_PREFS_WEB_ENABLE_WEBSITE_DATA_STORAGE  "enable-website-data-storage"
 #define EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL           "default-zoom-level"
 #define EPHY_PREFS_WEB_ENABLE_AUTOSEARCH            "enable-autosearch"
 #define EPHY_PREFS_WEB_ENABLE_MOUSE_GESTURES        "enable-mouse-gestures"
@@ -124,6 +107,8 @@ static const char * const ephy_prefs_state_schema[] = {
 #define EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY "hardware-acceleration-policy"
 #define EPHY_PREFS_WEB_ASK_ON_DOWNLOAD              "ask-on-download"
 #define EPHY_PREFS_WEB_SWITCH_TO_NEW_TAB            "switch-to-new-tab"
+#define EPHY_PREFS_WEB_ENABLE_WEBEXTENSIONS         "enable-webextensions"
+#define EPHY_PREFS_WEB_WEBEXTENSIONS_ACTIVE         "webextensions-active"
 
 static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_FONT_MIN_SIZE,
@@ -136,15 +121,14 @@ static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_ENABLE_USER_JS,
   EPHY_PREFS_WEB_ENABLE_POPUPS,
   EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING,
-  EPHY_PREFS_WEB_ENABLE_SMOOTH_SCROLLING,
   EPHY_PREFS_WEB_USER_AGENT,
-  EPHY_PREFS_WEB_COOKIES_POLICY,
   EPHY_PREFS_WEB_DEFAULT_ENCODING,
   EPHY_PREFS_WEB_ENABLE_ADBLOCK,
   EPHY_PREFS_WEB_REMEMBER_PASSWORDS,
   EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS,
   EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING,
-  EPHY_PREFS_WEB_GSB_API_KEY,
+  EPHY_PREFS_WEB_ENABLE_ITP,
+  EPHY_PREFS_WEB_ENABLE_WEBSITE_DATA_STORAGE,
   EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL,
   EPHY_PREFS_WEB_ENABLE_AUTOSEARCH,
   EPHY_PREFS_WEB_ENABLE_MOUSE_GESTURES,
@@ -153,6 +137,7 @@ static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY,
   EPHY_PREFS_WEB_ASK_ON_DOWNLOAD,
   EPHY_PREFS_WEB_SWITCH_TO_NEW_TAB,
+  EPHY_PREFS_WEB_ENABLE_WEBEXTENSIONS,
 };
 
 #define EPHY_PREFS_SCHEMA                             "org.gnome.Epiphany"
@@ -167,6 +152,8 @@ static const char * const ephy_prefs_web_schema[] = {
 #define EPHY_PREFS_DEFAULT_SEARCH_ENGINE              "default-search-engine"
 #define EPHY_PREFS_ASK_FOR_DEFAULT                    "ask-for-default"
 #define EPHY_PREFS_START_IN_INCOGNITO_MODE            "start-in-incognito-mode"
+#define EPHY_PREFS_ACTIVE_CLEAR_DATA_ITEMS            "active-clear-data-items"
+#define EPHY_PREFS_USE_GOOGLE_SEARCH_SUGGESTIONS      "use-google-search-suggestions"
 
 #define EPHY_PREFS_LOCKDOWN_SCHEMA            "org.gnome.Epiphany.lockdown"
 #define EPHY_PREFS_LOCKDOWN_FULLSCREEN        "disable-fullscreen"
@@ -196,11 +183,14 @@ static const char * const ephy_prefs_web_schema[] = {
 #define EPHY_PREFS_SYNC_HISTORY_INITIAL   "sync-history-initial"
 #define EPHY_PREFS_SYNC_OPEN_TABS_ENABLED "sync-open-tabs-enabled"
 #define EPHY_PREFS_SYNC_OPEN_TABS_TIME    "sync-open-tabs-time"
+#define EPHY_PREFS_SYNC_TOKEN_SERVER      "sync-token-server"
+#define EPHY_PREFS_SYNC_ACCOUNTS_SERVER   "sync-accounts-server"
 
-#define EPHY_PREFS_WEB_APP_SCHEMA            "org.gnome.Epiphany.webapp"
-#define EPHY_PREFS_WEB_APP_ADDITIONAL_URLS   "additional-urls"
-#define EPHY_PREFS_WEB_APP_MOBILE_CAPABLE    "mobile-capable"
-#define EPHY_PREFS_WEB_APP_RUN_IN_BACKGROUND "run-in-background"
+#define EPHY_PREFS_WEB_APP_SCHEMA                  "org.gnome.Epiphany.webapp"
+#define EPHY_PREFS_WEB_APP_ADDITIONAL_URLS         "additional-urls"
+#define EPHY_PREFS_WEB_APP_SHOW_NAVIGATION_BUTTONS "show-navigation-buttons"
+#define EPHY_PREFS_WEB_APP_RUN_IN_BACKGROUND       "run-in-background"
+#define EPHY_PREFS_WEB_APP_SYSTEM                  "system"
 
 static struct {
   const char *schema;
